Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1100)

Unified Diff: chrome/test/ui/ui_test.h

Issue 115740: Move download shelf from per-tab to per-window (Closed) Base URL: http://src.chromium.org/svn/trunk/src/
Patch Set: '' Created 11 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/test_browser_window.h ('k') | chrome/test/ui/ui_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/ui/ui_test.h
===================================================================
--- chrome/test/ui/ui_test.h (revision 17483)
+++ chrome/test/ui/ui_test.h (working copy)
@@ -172,11 +172,23 @@
// assert that the tab count is valid at the end of the wait.
void WaitUntilTabCount(int tab_count);
- // Checks whether the download shelf is visible in the current tab, giving it
- // a chance to appear (we don't know the exact timing) while finishing as soon
- // as possible.
- bool WaitForDownloadShelfVisible(TabProxy* tab);
+ // Checks whether the download shelf is visible in the current browser, giving
+ // it a chance to appear (we don't know the exact timing) while finishing as
+ // soon as possible.
+ bool WaitForDownloadShelfVisible(BrowserProxy* browser);
+ // Checks whether the download shelf is invisible in the current browser,
+ // giving it a chance to appear (we don't know the exact timing) while
+ // finishing as soon as possible.
+ bool WaitForDownloadShelfInvisible(BrowserProxy* browser);
+
+ private:
+ // Waits for download shelf visibility or invisibility.
+ bool WaitForDownloadShelfVisibilityChange(BrowserProxy* browser,
+ bool wait_for_open);
+
+ public:
+
// Waits until the Find window has become fully visible (if |wait_for_open| is
// true) or fully hidden (if |wait_for_open| is false). This function can time
// out (return false) if the window doesn't appear within a specific time.
« no previous file with comments | « chrome/test/test_browser_window.h ('k') | chrome/test/ui/ui_test.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698